@@ -45,6 +45,192 @@ extern "C" {
  * @{
  */
 
+/** Attribute value for VAConfigAttribEncHEVCFeatures.
+ *
+ * This attribute decribes the supported features of an HEVC/H.265
+ * encoder configuration.
+ *
+ * All of the field values in this attribute are VA_FEATURE_* values,
+ * indicating support for the corresponding feature.
+ */
+typedef union VAConfigAttribValEncHEVCFeatures {
+    struct {
+        /** Separate colour planes.
+         *
+         * Allows setting separate_colour_plane_flag in the SPS.
+         */
+        uint32_t separate_colour_planes     : 2;
+        /** Scaling lists.
+         *
+         * Allows scaling_list() elements to be present in both the SPS
+         * and the PPS.  The decoded form of the scaling lists must also
+         * be supplied in a VAQMatrixBufferHEVC buffer when scaling lists
+         * are enabled.
+         */
+        uint32_t scaling_lists              : 2;
+        /** Asymmetric motion partitions.
+         *
+         * Allows setting amp_enabled_flag in the SPS.
+         */
+        uint32_t amp                        : 2;
+        /** Sample adaptive offset filter.
+         *
+         * Allows setting slice_sao_luma_flag and slice_sao_chroma_flag
+         * in slice headers.
+         */
+        uint32_t sao                        : 2;
+        /** PCM sample blocks.
+         *
+         * Allows setting pcm_enabled_flag in the SPS.  When enabled
+         * PCM parameters must be supplied with the sequence parameters,
+         * including block sizes which may be further constrained as
+         * noted in the VAConfigAttribEncHEVCBlockSizes attribute.
+         */
+        uint32_t pcm                        : 2;
+        /** Temporal motion vector Prediction.
+         *
+         * Allows setting slice_temporal_mvp_enabled_flag in slice
+         * headers.
+         */
+        uint32_t temporal_mvp               : 2;
+        /** Strong intra smoothing.
+         *
+         * Allows setting strong_intra_smoothing_enabled_flag in the SPS.
+         */
+        uint32_t strong_intra_smoothing     : 2;
+        /** Dependent slices.
+         *
+         * Allows setting dependent_slice_segment_flag in slice headers.
+         */
+        uint32_t dependent_slices           : 2;
+        /** Sign data hiding.
+         *
+         * Allows setting sign_data_hiding_enable_flag in the PPS.
+         */
+        uint32_t sign_data_hiding           : 2;
+        /** Constrained intra prediction.
+         *
+         * Allows setting constrained_intra_pred_flag in the PPS.
+         */
+        uint32_t constrained_intra_pred     : 2;
+        /** Transform skipping.
+         *
+         * Allows setting transform_skip_enabled_flag in the PPS.
+         */
+        uint32_t transform_skip             : 2;
+        /** QP delta within coding units.
+         *
+         * Allows setting cu_qp_delta_enabled_flag in the PPS.
+         */
+        uint32_t cu_qp_delta                : 2;
+        /** Weighted prediction.
+         *
+         * Allows setting weighted_pred_flag and weighted_bipred_flag in
+         * the PPS.  The pred_weight_table() data must be supplied with
+         * every slice header when weighted prediction is enabled.
+         */
+        uint32_t weighted_prediction        : 2;
+        /** Transform and quantisation bypass.
+         *
+         * Allows setting transquant_bypass_enabled_flag in the PPS.
+         */
+        uint32_t transquant_bypass          : 2;
+        /** Deblocking filter disable.
+         *
+         * Allows setting slice_deblocking_filter_disabled_flag.
+         */
+        uint32_t deblocking_filter_disable  : 2;
+        /* Reserved,should not be used, avoid conflict with VA_ATTRIB_NOT_SUPPORTED. */
+        uint32_t reserved                   : 2;
+    } bits;
+    uint32_t value;
+} VAConfigAttribValEncHEVCFeatures;
+
+/** Attribute value for VAConfigAttribEncHEVCBlockSizes.
+ *
+ * This attribute describes the supported coding tree and transform block
+ * sizes of an HEVC/H.265 encoder configuration
+ */
+typedef union VAConfigAttribValEncHEVCBlockSizes {
+    struct {
+        /** Largest supported size of coding tree blocks.
+         *
+         * CtbLog2SizeY must not be larger than this.
+         */
+        uint32_t log2_max_coding_tree_block_size_minus3    : 2;
+        /** Smallest supported size of coding tree blocks.
+         *
+         * CtbLog2SizeY must not be smaller than this.
+         *
+         * This may be the same as the maximum size, indicating that only
+         * one CTB size is supported.
+         */
+        uint32_t log2_min_coding_tree_block_size_minus3    : 2;
+
+        /** Smallest supported size of luma coding blocks.
+         *
+         * MinCbLog2SizeY must not be smaller than this.
+         */
+        uint32_t log2_min_luma_coding_block_size_minus3    : 2;
+
+        /** Largest supported size of luma transform blocks.
+         *
+         * MaxTbLog2SizeY must not be larger than this.
+         */
+        uint32_t log2_max_luma_transform_block_size_minus2 : 2;
+        /** Smallest supported size of luma transform blocks.
+         *
+         * MinTbLog2SizeY must not be smaller than this.
+         */
+        uint32_t log2_min_luma_transform_block_size_minus2 : 2;
+
+        /** Largest supported transform hierarchy depth in inter
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_inter must not be larger
+         * than this.
+         */
+        uint32_t max_max_transform_hierarchy_depth_inter   : 2;
+        /** Smallest supported transform hierarchy depth in inter
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_inter must not be smaller
+         * than this.
+         */
+        uint32_t min_max_transform_hierarchy_depth_inter   : 2;
+
+        /** Largest supported transform hierarchy depth in intra
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_intra must not be larger
+         * than this.
+         */
+        uint32_t max_max_transform_hierarchy_depth_intra   : 2;
+        /** Smallest supported transform hierarchy depth in intra
+         *  coding units.
+         *
+         * max_transform_hierarchy_depth_intra must not be smaller
+         * than this.
+         */
+        uint32_t min_max_transform_hierarchy_depth_intra   : 2;
+
+        /** Largest supported size of PCM coding blocks.
+         *
+         *  Log2MaxIpcmCbSizeY must not be larger than this.
+         */
+        uint32_t log2_max_pcm_coding_block_size_minus3     : 2;
+        /** Smallest supported size of PCM coding blocks.
+         *
+         *  Log2MinIpcmCbSizeY must not be smaller than this.
+         */
+        uint32_t log2_min_pcm_coding_block_size_minus3     : 2;
+
+        /** Reserved for future use. */
+        uint32_t reserved                                  : 10;
+    } bits;
+    uint32_t value;
+} VAConfigAttribValEncHEVCBlockSizes;
+
 /**
  * @name Picture flags
  *
@@ -128,8 +314,13 @@ typedef enum {
      * sei_message() elements if necessary.
      *
      * Note: packed \c nal_unit_type shall be equal to 39 or 40.
+     *
+     * @deprecated
+     * This is a deprecated packed header flag, All applications can use
+     * \c VA_ENC_PACKED_HEADER_RAW_DATA to pass the corresponding packed
+     * SEI header data buffer to the driver
      */
-    VAEncPackedHeaderHEVC_SEI   = (VAEncPackedHeaderMiscMask | 1),
+    VAEncPackedHeaderHEVC_SEI  va_deprecated_enum = (0x80000000 | 1),
 } VAEncPackedHeaderTypeHEVC;
 
 /**
@@ -217,8 +408,19 @@ typedef struct _VAEncSequenceParameterBufferHEVC {
             uint32_t    pcm_loop_filter_disabled_flag                  : 1;
             /** \brief Same as the HEVC bitstream syntax element. */
             uint32_t    sps_temporal_mvp_enabled_flag                  : 1;
-
-            uint32_t    reserved_bits                                  : 16;
+            /** \brief Indicates whether or not the encoding is in low delay mode.
+              * 0 normal sequence
+              * 1 no random access B will be coded . and the coding type could be only I, P or LDB
+              * this flag only indicates the frame coding type of the sequence.
+              */
+            uint32_t    low_delay_seq                                  : 1;
+            /** \brief Indicates whether or not the encoding is in dyadic hierarchical GOP structure
+              * the default value 0, BRC would treat is as flat structure. if HierachicalFlag == 1,
+              * application would enable Qp Modulation
+              */
+            uint32_t    hierachical_flag                               : 1;
+            /** \brief keep for future , should be set to 0 */
+            uint32_t    reserved_bits                                  : 14;
         } bits;
         uint32_t value;
     } seq_fields;
@@ -311,6 +513,19 @@ typedef struct _VAEncSequenceParameterBufferHEVC {
     uint8_t     max_bytes_per_pic_denom;
     /** \brief Same as the HEVC bitstream syntax element. */
     uint8_t     max_bits_per_min_cu_denom;
+
+    /** \brief SCC flags to enable/disable features, including IBC and palette mode at present.*/
+    union {
+        struct {
+            /** \brief Same as the HEVC bitstream syntax element. */
+            uint32_t    palette_mode_enabled_flag                      : 1;
+            /** \brief Reserved bits for future use, must be zero */
+            uint32_t    reserved                                       : 31;
+        } bits;
+        uint32_t value;
+    } scc_fields;
+    /** \brief Reserved bytes for future use, must be zero */
+    uint32_t   va_reserved[VA_PADDING_MEDIUM - 1];
     /**@}*/
 } VAEncSequenceParameterBufferHEVC;
 
@@ -512,6 +727,27 @@ typedef struct _VAEncPictureParameterBufferHEVC {
         } bits;
         uint32_t        value;
     } pic_fields;
+
+    /** \brief When hierachical_level_plus1 > 0, hierachical_level_plus1-1 indicates
+     *the current frame's level.when it > 0. B1, B2 setting in CodingType can be treated as B,
+     *hirachical level is determined by this variable.When hierachical_level_plus1  == 0,
+     *hierarchical level information still comes from coding_type.
+     */
+    uint8_t     hierarchical_level_plus1;
+    /** \brief Reserved bytes for future use, must be zero */
+    uint8_t     va_byte_reserved;
+    /** \brief SCC flags to enable/disable feature, only IBC at present.*/
+    union {
+        struct {
+            /** \brief Same as the HEVC bitstream syntax element. */
+            uint16_t    pps_curr_pic_ref_enabled_flag                  : 1;
+            /** \brief Reserved bits for future use, must be zero */
+            uint16_t    reserved                                       : 15;
+        } bits;
+        uint16_t value;
+    } scc_fields;
+    /** \brief Reserved bytes for future use, must be zero */
+    uint32_t                va_reserved[VA_PADDING_HIGH - 1];
 } VAEncPictureParameterBufferHEVC;
 
 /**
@@ -635,6 +871,25 @@ typedef struct _VAEncSliceParameterBufferHEVC {
         } bits;
         uint32_t        value;
     } slice_fields;
+
+
+    /**
+     * \brief bit offset of syntax element pred_weight_table() in slice segment header.
+     * It aligns with the starting position of the current packed slice header.
+     * It is used when encoder prefers to override the weighted prediction parameters passed in
+     * from application.
+     * Please refer to enable_gpu_weighted_prediction in VAEncPictureParameterBufferHEVC.
+     */
+    uint32_t                pred_weight_table_bit_offset;
+    /**
+     * \brief bit length of syntax element pred_weight_table() in slice segment header.
+     * It is used when encoder prefers to override the weighted prediction parameters passed in
+     * from application.
+     * Please refer to enable_gpu_weighted_prediction in VAEncPictureParameterBufferHEVC.
+    */
+    uint32_t                pred_weight_table_bit_length;
+    /** \brief Reserved bytes for future use, must be zero */
+    uint32_t                va_reserved[VA_PADDING_MEDIUM-2];
     /**@}*/
 } VAEncSliceParameterBufferHEVC;
 
@@ -690,6 +945,9 @@ typedef struct _VAQMatrixBufferHEVC
      * with sizeID = 3 and matrixID in the range of 0 to 1, inclusive.
      */
     uint8_t             scaling_list_dc_32x32[2];
+
+    /** \brief Reserved bytes for future use, must be zero */
+    uint32_t                va_reserved[VA_PADDING_LOW];
 } VAQMatrixBufferHEVC;
 
 /**@}*/
